@@ -3,7 +3,7 @@ use warnings;
 
 package JSON::Typist;
 # ABSTRACT: replace mushy strings and numbers with rigidly typed replacements
-$JSON::Typist::VERSION = '0.004';
+$JSON::Typist::VERSION = '0.005';
 #pod =head1 OVERVIEW
 #pod
 #pod JSON is super useful and everybody loves it.  Woo!  Go JSON!  Good job!
@@ -56,7 +56,7 @@ use Scalar::Util qw(blessed);
 
 {
   package JSON::Typist::Number;
-$JSON::Typist::Number::VERSION = '0.004';
+$JSON::Typist::Number::VERSION = '0.005';
 use overload '0+' => sub { ${ $_[0] } }, fallback => 1;
   sub new { my $x = $_[1]; bless \$x, $_[0] }
   sub TO_JSON { 0 + ${$_[0]} }
@@ -64,7 +64,7 @@ use overload '0+' => sub { ${ $_[0] } }, fallback => 1;
 
 {
   package JSON::Typist::String;
-$JSON::Typist::String::VERSION = '0.004';
+$JSON::Typist::String::VERSION = '0.005';
 use overload '""' => sub { ${ $_[0] } }, fallback => 1;
   sub new { my $x = $_[1]; bless \$x, $_[0] }
   sub TO_JSON { "${$_[0]}" }
@@ -161,6 +161,21 @@ sub strip_types {
   return $data;
 }
 
+#pod =method number
+#pod
+#pod =method string
+#pod
+#pod   my $jnum = $typist->number(123);
+#pod   my $jstr = $typist->string(123);
+#pod
+#pod These methods returns the same sorts of objects that would be returned in a
+#pod typed JSON structure from C<apply_types>.
+#pod
+#pod =cut
+
+sub number { my ($self, $value) = @_; JSON::Typist::Number->new($value) }
+sub string { my ($self, $value) = @_; JSON::Typist::String->new($value) }
+
 1;
 
 __END__
@@ -175,7 +190,7 @@ JSON::Typist - replace mushy strings and numbers with rigidly typed replacements
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
@@ -256,6 +271,16 @@ should not be needed if your JSON decoder has C<convert_blessed> enabled.
 Right now, boolean objects are left in place, because they will be there from
 JSON's behavior, not JSON::Typist.  This may change in the future.
 
+=head2 number
+
+=head2 string
+
+  my $jnum = $typist->number(123);
+  my $jstr = $typist->string(123);
+
+These methods returns the same sorts of objects that would be returned in a
+typed JSON structure from C<apply_types>.
+
 =head1 AUTHOR
 
 Ricardo Signes <rjbs@cpan.org>
